==> kubernetes-model-1.0.62-sources.jar: io/fabric8/kubernetes/api/model/extensions/PetSetFluentImpl.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.String;
import javax.validation.constraints.NotNull;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import javax.validation.Valid;
import io.fabric8.kubernetes.api.model.validators.CheckObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import java.lang.Long;
import java.lang.Integer;
import java.lang.Object;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;

public class PetSetFluentImpl<A extends PetSetFluent<A>> extends BaseFluent<A> implements PetSetFluent<A>{

    private String apiVersion;
    private String kind;
    private VisitableBuilder<? extends ObjectMeta,?> metadata;
    private VisitableBuilder<? extends PetSetSpec,?> spec;
    private VisitableBuilder<? extends PetSetStatus,?> status;

    public PetSetFluentImpl(){
    }
    public PetSetFluentImpl(PetSet instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withSpec(instance.getSpec()); 
            this.withStatus(instance.getStatus()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata){
            if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.add(this.metadata);} return (A) this;
    }

    public PetSetFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public PetSetFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public PetSetFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public PetSetSpec getSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(PetSetSpec spec){
            if (spec!=null){ this.spec= new PetSetSpecBuilder(spec); _visitables.add(this.spec);} return (A) this;
    }

    public PetSetFluent.SpecNested<A> withNewSpec(){
            return new SpecNestedImpl();
    }

    public PetSetFluent.SpecNested<A> withNewSpecLike(PetSetSpec item){
            return new SpecNestedImpl(item);
    }

    public PetSetFluent.SpecNested<A> editSpec(){
            return withNewSpecLike(getSpec());
    }

    public PetSetStatus getStatus(){
            return this.status!=null?this.status.build():null;
    }

    public A withStatus(PetSetStatus status){
            if (status!=null){ this.status= new PetSetStatusBuilder(status); _visitables.add(this.status);} return (A) this;
    }

    public PetSetFluent.StatusNested<A> withNewStatus(){
            return new StatusNestedImpl();
    }

    public PetSetFluent.StatusNested<A> withNewStatusLike(PetSetStatus item){
            return new StatusNestedImpl(item);
    }

    public PetSetFluent.StatusNested<A> editStatus(){
            return withNewStatusLike(getStatus());
    }

    public A withNewStatus(Long observedGeneration,Integer replicas){
            return (A)withStatus(new PetSetStatus(observedGeneration, replicas));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            PetSetFluentImpl that = (PetSetFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
            if (status != null ? !status.equals(that.status) :that.status != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<PetSetFluent.MetadataNested<N>> implements PetSetFluent.MetadataNested<N>,Nested<N>{

            private final ObjectMetaBuilder builder;
    
            MetadataNestedImpl(ObjectMeta item){
                    this.builder = new ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) PetSetFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}
    public class SpecNestedImpl<N> extends PetSetSpecFluentImpl<PetSetFluent.SpecNested<N>> implements PetSetFluent.SpecNested<N>,Nested<N>{

            private final PetSetSpecBuilder builder;
    
            SpecNestedImpl(){
                    this.builder = new PetSetSpecBuilder(this);
            }
            SpecNestedImpl(PetSetSpec item){
                    this.builder = new PetSetSpecBuilder(this, item);
            }
    
    public N endSpec(){
            return and();
    }
    public N and(){
            return (N) PetSetFluentImpl.this.withSpec(builder.build());
    }

}
    public class StatusNestedImpl<N> extends PetSetStatusFluentImpl<PetSetFluent.StatusNested<N>> implements PetSetFluent.StatusNested<N>,Nested<N>{

            private final PetSetStatusBuilder builder;
    
            StatusNestedImpl(){
                    this.builder = new PetSetStatusBuilder(this);
            }
            StatusNestedImpl(PetSetStatus item){
                    this.builder = new PetSetStatusBuilder(this, item);
            }
    
    public N and(){
            return (N) PetSetFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus(){
            return and();
    }

}


}

==> kubernetes-model-1.0.64-sources.jar: io/fabric8/kubernetes/api/model/extensions/PetSetFluentImpl.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.validators.CheckObjectMeta;
import java.lang.String;
import javax.validation.constraints.NotNull;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import io.sundr.builder.annotations.Buildable;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import javax.annotation.Generated;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Integer;
import javax.validation.Valid;
import java.lang.Long;
import java.lang.Object;
import lombok.ToString;

public class PetSetFluentImpl<A extends PetSetFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements PetSetFluent<A>{

    private String apiVersion;
    private String kind;
    private VisitableBuilder<? extends ObjectMeta,?> metadata;
    private VisitableBuilder<? extends PetSetSpec,?> spec;
    private VisitableBuilder<? extends PetSetStatus,?> status;

    public PetSetFluentImpl(){
    }
    public PetSetFluentImpl(PetSet instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withSpec(instance.getSpec()); 
            this.withStatus(instance.getStatus()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata){
            _visitables.remove(this.metadata);
            if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.add(this.metadata);} return (A) this;
    }

    public PetSetFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public PetSetFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public PetSetFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public PetSetFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public PetSetFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    public PetSetSpec getSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(PetSetSpec spec){
            _visitables.remove(this.spec);
            if (spec!=null){ this.spec= new PetSetSpecBuilder(spec); _visitables.add(this.spec);} return (A) this;
    }

    public PetSetFluent.SpecNested<A> withNewSpec(){
            return new SpecNestedImpl();
    }

    public PetSetFluent.SpecNested<A> withNewSpecLike(PetSetSpec item){
            return new SpecNestedImpl(item);
    }

    public PetSetFluent.SpecNested<A> editSpec(){
            return withNewSpecLike(getSpec());
    }

    public PetSetFluent.SpecNested<A> editOrNewSpec(){
            return withNewSpecLike(getSpec() != null ? getSpec(): new PetSetSpecBuilder().build());
    }

    public PetSetFluent.SpecNested<A> editOrNewSpecLike(PetSetSpec item){
            return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    public PetSetStatus getStatus(){
            return this.status!=null?this.status.build():null;
    }

    public A withStatus(PetSetStatus status){
            _visitables.remove(this.status);
            if (status!=null){ this.status= new PetSetStatusBuilder(status); _visitables.add(this.status);} return (A) this;
    }

    public PetSetFluent.StatusNested<A> withNewStatus(){
            return new StatusNestedImpl();
    }

    public PetSetFluent.StatusNested<A> withNewStatusLike(PetSetStatus item){
            return new StatusNestedImpl(item);
    }

    public PetSetFluent.StatusNested<A> editStatus(){
            return withNewStatusLike(getStatus());
    }

    public PetSetFluent.StatusNested<A> editOrNewStatus(){
            return withNewStatusLike(getStatus() != null ? getStatus(): new PetSetStatusBuilder().build());
    }

    public PetSetFluent.StatusNested<A> editOrNewStatusLike(PetSetStatus item){
            return withNewStatusLike(getStatus() != null ? getStatus(): item);
    }

    public A withNewStatus(Long observedGeneration,Integer replicas){
            return (A)withStatus(new PetSetStatus(observedGeneration, replicas));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            PetSetFluentImpl that = (PetSetFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
            if (status != null ? !status.equals(that.status) :that.status != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<PetSetFluent.MetadataNested<N>> implements PetSetFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ObjectMetaBuilder builder;
    
            MetadataNestedImpl(ObjectMeta item){
                    this.builder = new ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) PetSetFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}
    public class SpecNestedImpl<N> extends PetSetSpecFluentImpl<PetSetFluent.SpecNested<N>> implements PetSetFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final PetSetSpecBuilder builder;
    
            SpecNestedImpl(PetSetSpec item){
                    this.builder = new PetSetSpecBuilder(this, item);
            }
            SpecNestedImpl(){
                    this.builder = new PetSetSpecBuilder(this);
            }
    
    public N and(){
            return (N) PetSetFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec(){
            return and();
    }

}
    public class StatusNestedImpl<N> extends PetSetStatusFluentImpl<PetSetFluent.StatusNested<N>> implements PetSetFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final PetSetStatusBuilder builder;
    
            StatusNestedImpl(PetSetStatus item){
                    this.builder = new PetSetStatusBuilder(this, item);
            }
            StatusNestedImpl(){
                    this.builder = new PetSetStatusBuilder(this);
            }
    
    public N and(){
            return (N) PetSetFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus(){
            return and();
    }

}


}
